pub struct MetadataOperation {
pub entity_id: EntityId,
pub actions: OneOrMany<MetadataAction>,
}Expand description
A metadata operation.
Operations involve a number of actions to perform in the context of the given entity. Such actions typically include setting tags or establishing ancestry links.
Fields
entity_id: EntityIdThe entity ID this operation is associated with.
actions: OneOrMany<MetadataAction>The actions to perform.
Implementations
Sourceimpl MetadataOperation
impl MetadataOperation
Sourcepub fn add_alias(entity_id: EntityId, target_entity_id: EntityId) -> Self
pub fn add_alias(entity_id: EntityId, target_entity_id: EntityId) -> Self
Creates a new MetadataOperation that aliases an entity to another.
Sourcepub fn remove_alias(entity_id: EntityId, target_entity_id: EntityId) -> Self
pub fn remove_alias(entity_id: EntityId, target_entity_id: EntityId) -> Self
Creates a new MetadataOperation that removes an alias to another entity.
Sourcepub fn delete(entity_id: EntityId) -> Self
pub fn delete(entity_id: EntityId) -> Self
Creates a new MetadataOperation that deletes all metadata for an entity.
Sourcepub fn attach_external_data(
entity_id: EntityId,
external_data: ExternalData,
) -> Self
pub fn attach_external_data( entity_id: EntityId, external_data: ExternalData, ) -> Self
Creates a new MetadataOperation that attaches External Data to an entity.