OnDemandPIDResolver

Struct OnDemandPIDResolver 

pub struct OnDemandPIDResolver { /* private fields */ }
A resolver for mapping process IDs to their container IDs based on querying the underlying host.

Platform support

On Linux, PIDs are resolved by querying procfs to find the cgroup of the process, if one exists, the cgroup hierarchy is queried to discover the container ID that owns the process, if possible.

On all other platforms, resolving a PID is a no-op.

Implementations

Source

impl OnDemandPIDResolver

pub fn new( procfs_root: Option<PathBuf>, cgroupfs_root: Option<PathBuf>, feature_detector: &FeatureDetector, interner: GenericMapInterner, ) -> Result<Self, GenericError>

Creates a new OnDemandPIDResolver for the given container filesystem roots.

If a root is given, that path is used. Otherwise, it is resolved from the detected features.

Errors

On Linux, if a cgroups hierarchy can’t be found, or the internal cache can’t be created, an error is returned. On all other platforms, no error is possible.

pub fn resolve(&self, process_id: u32) -> Option<EntityId>

Resolves a process ID to the container ID of the container is part of.

If the process ID isn’t part of a container, or can’t be found, None is returned.

pub fn resolve_self_container(&self) -> Option<EntityId>

Resolves the current process’s container entity from local cgroup membership.

On non-Linux platforms, or when the process is not in a recognizable container cgroup, this returns None.