pub enum MetadataAction {
Delete,
AddAlias {
target_entity_id: EntityId,
},
RemoveAlias {
target_entity_id: EntityId,
},
SetTags {
cardinality: OriginTagCardinality,
tags: TagSet,
},
AttachExternalData {
external_data: ExternalData,
},
}Expand description
A metadata action.
Variants
Delete
Delete all metadata for the entity.
AddAlias
Adds an alias to the entity.
This can be used to allow for querying for information about an entity, where the information isn’t directly associated with the entity itself. For example, process ID entities usually are aliased to an underlying container ID entity, where the container ID entity itself is the one with associated tags and so on. When querying for the tags of the process ID entity, an alias to the container ID entity can be established to instead allow for getting the container ID entity’s tags.
RemoveAlias
Removes an alias to the entity.
SetTags
Sets the tags for the entity.
This overwrites any existing tags for the entity.
AttachExternalData
Attaches External Data to the entity.
External Data is free-form string data that’s attached to entities from external systems to allow resolving the entity’s ID when it can’t be passed directly to the entity such that the entity can provide it in telemetry payloads itself.
Fields
external_data: ExternalDataExternal Data to attach.