pub struct OnDemandPIDResolver { /* private fields */ }Expand description
A resolver for mapping process IDs to their container IDs based on querying the underlying host.
Platform support
On Linux platforms, PIDs are resolved by querying procfs to find the cgroup of the process, if one exists, the cgroup hierarchy is queried to discover the container ID that owns the process, if possible.
On all other platforms, OnDemandPIDResolver is a no-op and doesn’t perform any resolution.
Implementations
Sourceimpl OnDemandPIDResolver
impl OnDemandPIDResolver
Sourcepub fn from_configuration(
config: &GenericConfiguration,
feature_detector: FeatureDetector,
interner: GenericMapInterner,
) -> Result<Self, GenericError>
pub fn from_configuration( config: &GenericConfiguration, feature_detector: FeatureDetector, interner: GenericMapInterner, ) -> Result<Self, GenericError>
Creates a new OnDemandPIDResolver from the given configuration.
Errors
If a cgroups hierarchy can’t be found, or the internal cache can’t be created, an error is returned.